Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(915)

Unified Diff: net/quic/quic_session.cc

Issue 530343003: Landing Recent QUIC Changes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@Final_0828
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_sent_packet_manager_test.cc ('k') | net/quic/quic_unacked_packet_map.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_session.cc
diff --git a/net/quic/quic_session.cc b/net/quic/quic_session.cc
index d327da69da47e18db9322817e12469390958d859..91d8e55e454e6d54391b47a16c55956fd23f84e4 100644
--- a/net/quic/quic_session.cc
+++ b/net/quic/quic_session.cc
@@ -272,7 +272,7 @@ void QuicSession::OnWindowUpdateFrames(
continue;
}
- if (connection_->version() <= QUIC_VERSION_20 &&
+ if (connection_->version() <= QUIC_VERSION_21 &&
(stream_id == kCryptoStreamId || stream_id == kHeadersStreamId)) {
DLOG(DFATAL) << "WindowUpdate for stream " << stream_id << " in version "
<< QuicVersionToString(connection_->version());
@@ -500,7 +500,7 @@ void QuicSession::OnConfigNegotiated() {
return;
}
// QUIC_VERSION_20 and higher can have independent stream and session flow
// control windows.
if (config_.HasReceivedInitialStreamFlowControlWindowBytes()) {
// Streams which were created before the SHLO was received (0-RTT
@@ -526,7 +526,7 @@ void QuicSession::OnNewStreamFlowControlWindow(uint32 new_window) {
}
// Inform all existing streams about the new window.
- if (connection_->version() > QUIC_VERSION_20) {
+ if (connection_->version() >= QUIC_VERSION_21) {
GetCryptoStream()->flow_controller()->UpdateSendWindowOffset(new_window);
headers_stream_->flow_controller()->UpdateSendWindowOffset(new_window);
}
@@ -759,7 +759,7 @@ void QuicSession::OnSuccessfulVersionNegotiation(const QuicVersion& version) {
// Disable stream level flow control based on negotiated version. Streams may
// have been created with a different version.
- if (version <= QUIC_VERSION_20) {
+ if (version < QUIC_VERSION_21) {
GetCryptoStream()->flow_controller()->Disable();
headers_stream_->flow_controller()->Disable();
}
@@ -500,7 +500,7 @@ void QuicSession::OnConfigNegotiated() {
return;
}
- // QUIC_VERSION_20 and higher can have independent stream and session flow
+ // QUIC_VERSION_21 and higher can have independent stream and session flow
// control windows.
if (config_.HasReceivedInitialStreamFlowControlWindowBytes()) {
« no previous file with comments | « net/quic/quic_sent_packet_manager_test.cc ('k') | net/quic/quic_unacked_packet_map.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698